@@ -1,4 +1,4 @@
-import AioPTTCrawler
+from AioPTTCrawler import AioPTTCrawler
 
 def main():
     ptt_crawler = AioPTTCrawler()
